// Package v2 provides migration for mongo repository
package v2

import (
	"context"
	"time"

	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
	v1 "gitlab.mashplace.com/mashplace/backend/extras/internal/model/mongo/migrations/v1"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/bson/primitive"
	"go.mongodb.org/mongo-driver/mongo"
)

// ExtraServiceModel v2 model version
type ExtraServiceModel struct {
	Created            time.Time            `bson:"created"`
	Updated            time.Time            `bson:"updated"`
	Code               string               `bson:"code"`
	Title              string               `bson:"description"`
	Description        string               `bson:"learn_more"`
	Price              float64              `bson:"price"`
	ID                 primitive.ObjectID   `bson:"_id"`
	Type               extras.ServiceType   `bson:"type"`
	Role               extras.ServiceRole   `bson:"role"`
	Status             extras.ServiceStatus `bson:"status"`
	PriceCalculated    bool                 `bson:"price_calculated"`
	PriceNeedCalculate bool                 `bson:"price_need_calculate"`
	PriceOnRequest     bool                 `bson:"price_on_request"`
	Primary            bool                 `bson:"primary"`
	Obligatory         bool                 `bson:"obligatory"`
}

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	cur, err := col.Find(ctx, bson.M{})
	if err != nil {
		return -1, err
	}

	for cur.Next(ctx) {
		prevmodel := &v1.ExtraServiceModel{}

		err = cur.Decode(prevmodel)
		if err != nil {
			continue
		}

		id := prevmodel.ID

		newmodel := &ExtraServiceModel{
			ID:                 id,
			Code:               prevmodel.Code,
			Type:               prevmodel.Type,
			Role:               prevmodel.Role,
			Status:             prevmodel.Status,
			Price:              prevmodel.Price,
			Title:              prevmodel.Description,
			Primary:            prevmodel.Primary,
			Created:            prevmodel.Created,
			Obligatory:         true,
			Description:        "",
			PriceNeedCalculate: false,
			PriceCalculated:    false,
			PriceOnRequest:     false,
		}

		_, err = col.ReplaceOne(ctx, bson.M{"_id": id}, newmodel)
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
