// Package v6 provides migration for mongo repository
package v6

import (
	"context"

	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
	"gitlab.mashplace.com/mashplace/backend/extras/internal/model"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up adds service data into extras collection
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	col := db.Collection("extras")

	_, err := col.InsertOne(ctx, &model.Service{
		Code:          "landlord_rent_guarantee_insurance",
		Title:         "Rent Guarantee Insurance",
		Description:   "Protect your rental income by insuring any unpaid rent and your legal expenses.",
		Type:          extras.ServiceType_RENT_GUARANTEE_INSURANCE,
		Role:          extras.ServiceRole_LANDLORD_SERVICES,
		Status:        extras.ServiceStatus_ACTIVE,
		Price:         266.96,
		TaxAmount:     32.04,
		TaxPercentage: 12,
		TaxType:       extras.TaxType_TAX_TYPE_IPT,
		CartProduct:   true,
	})
	if err != nil {
		return -1, err
	}

	_, err = col.UpdateOne(ctx, bson.M{"code": "tenant_contents_insurance"}, bson.M{"$set": bson.M{
		"role":           extras.ServiceRole_TENANT_SERVICES,
		"tax_percentage": 12.0,
		"tax_type":       extras.TaxType_TAX_TYPE_IPT,
	}})

	return -1, err
}
