package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"

	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
)

// Service provides persistent model for service representation
type Service struct {
	Attributes         map[extras.AttributeCode]string `bson:"attributes"`
	Created            time.Time                       `bson:"created"`
	Updated            time.Time                       `bson:"updated"`
	Code               string                          `bson:"code"`
	Title              string                          `bson:"title"`
	Description        string                          `bson:"description"`
	ReferenceProvider  string                          `bson:"reference_provider"`
	ReferenceID        string                          `bson:"reference_id"`
	PageURL            string                          `bson:"page_url"`
	MainIconURL        string                          `bson:"main_icon_url"`
	InventoryAccount   string                          `bson:"inventory_account"`
	InventoryCode      string                          `bson:"inventory_code"`
	ServiceReceivers   []*ServiceReceiver              `bson:"service_receivers"`
	Price              float64                         `bson:"price"`
	TaxAmount          float64                         `bson:"tax_amount"`
	TaxPercentage      float64                         `bson:"tax_percentage"`
	InventoryIndex     int                             `bson:"-"`
	InventoryOffset    int32                           `bson:"inventory_offset"`
	Type               extras.ServiceType              `bson:"type"`
	Role               extras.ServiceRole              `bson:"role"`
	Status             extras.ServiceStatus            `bson:"status"`
	TaxType            extras.TaxType                  `bson:"tax_type"`
	ID                 primitive.ObjectID              `bson:"_id,omitempty"`
	Primary            bool                            `bson:"primary"`
	CartProduct        bool                            `bson:"cart_product"`
	Disabled           bool                            `bson:"disabled"`
	Obligatory         bool                            `bson:"obligatory"`
	PriceCalculated    bool                            `bson:"price_calculated"`
	PriceNeedCalculate bool                            `bson:"price_need_calculate"`
	PriceOnRequest     bool                            `bson:"price_on_request"`
}

// ServiceHistory provides history model for service representation
type ServiceHistory struct {
	Attributes         map[extras.AttributeCode]string `bson:"attributes"`
	Created            time.Time                       `bson:"created"`
	Updated            time.Time                       `bson:"updated"`
	Code               string                          `bson:"code"`
	Title              string                          `bson:"title"`
	Description        string                          `bson:"description"`
	ReferenceProvider  string                          `bson:"reference_provider"`
	ReferenceID        string                          `bson:"reference_id"`
	PageURL            string                          `bson:"page_url"`
	MainIconURL        string                          `bson:"main_icon_url"`
	InventoryAccount   string                          `bson:"inventory_account"`
	InventoryCode      string                          `bson:"inventory_code"`
	ServiceID          string                          `bson:"service_id"`
	Action             string                          `bson:"action"`
	ServiceReceivers   []*ServiceReceiver              `bson:"service_receivers"`
	Price              float64                         `bson:"price"`
	TaxAmount          float64                         `bson:"tax_amount"`
	TaxPercentage      float64                         `bson:"tax_percentage"`
	InventoryIndex     int                             `bson:"-"`
	InventoryOffset    int32                           `bson:"inventory_offset"`
	Type               extras.ServiceType              `bson:"type"`
	Role               extras.ServiceRole              `bson:"role"`
	Status             extras.ServiceStatus            `bson:"status"`
	TaxType            extras.TaxType                  `bson:"tax_type"`
	ID                 primitive.ObjectID              `bson:"_id,omitempty"`
	Primary            bool                            `bson:"primary"`
	CartProduct        bool                            `bson:"cart_product"`
	Disabled           bool                            `bson:"disabled"`
	Obligatory         bool                            `bson:"obligatory"`
	PriceCalculated    bool                            `bson:"price_calculated"`
	PriceNeedCalculate bool                            `bson:"price_need_calculate"`
	PriceOnRequest     bool                            `bson:"price_on_request"`
}

// ServiceReceiver provides model for something
type ServiceReceiver struct {
	Code    string  `bson:"code"`
	Percent float64 `bson:"percent"`
	Sum     float64 `bson:"sum"`
}
