package test

import (
	"errors"

	"github.com/golang/mock/gomock"
	extras "gitlab.mashplace.com/mashplace/backend/extras/api"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func (s *serviceSuite) TestExtrasAdd_ok() {
	m := extras.AddRequest{
		ExtraService: &extras.Service{},
		Placeholder:  true,
	}

	s.repo.EXPECT().ServiceCreate(s.testCtx, gomock.Any())

	resp, err := s.srv.Add(s.testCtx, &m)

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestExtrasAdd_err() {
	m := extras.AddRequest{
		ExtraService: &extras.Service{
			Code: &extras.Service_CodeValue{
				CodeValue: "",
			},
		},
		Placeholder: true,
	}

	resp, err := s.srv.Add(s.testCtx, &m)

	s.Require().EqualError(err, "code empty")

	s.Require().Nil(resp)
}

func (s *serviceSuite) TestExtrasAdd_repoErr() {
	k := primitive.NewObjectID()
	m := extras.AddRequest{
		ExtraService: &extras.Service{
			Code: &extras.Service_CodeValue{
				CodeValue: k.String(),
			},
		},
		Placeholder: true,
	}

	s.repo.EXPECT().ServiceExistsByCode(s.testCtx, gomock.Any())

	s.repo.EXPECT().ServiceCreate(s.testCtx, gomock.Any()).
		Return(errors.New("some error add"))

	resp, err := s.srv.Add(s.testCtx, &m)

	s.Require().EqualError(err, "some error add")

	s.Require().Nil(resp)
}
